# Generated by Django 2.1.2 on 2019-07-31 10:43

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Action',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('command', models.CharField(max_length=200)),
                ('added', models.DateTimeField(auto_now_add=True)),
                ('executed', models.DateTimeField(blank=True, null=True)),
                ('return_code', models.IntegerField(blank=True, null=True)),
                ('output', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Device',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('mac', models.CharField(max_length=45, unique=True)),
                ('name', models.CharField(blank=True, max_length=200, null=True, verbose_name='Navn')),
                ('description', models.CharField(blank=True, max_length=200, null=True, verbose_name='Beskrivelse')),
                ('message', models.CharField(blank=True, max_length=200, null=True)),
                ('ip', models.GenericIPAddressField(blank=True, null=True)),
                ('last_seen', models.DateTimeField(blank=True, null=True, verbose_name='Sist sett')),
                ('number', models.IntegerField(blank=True, null=True, verbose_name='Nummer')),
                ('monitored_process', models.CharField(blank=True, max_length=200, null=True)),
                ('uptime', models.CharField(blank=True, max_length=200, null=True, verbose_name='Oppetid')),
                ('screen_status', models.CharField(blank=True, max_length=200, null=True, verbose_name='Skjermstatus')),
                ('serial', models.CharField(blank=True, max_length=50, null=True, unique=True, verbose_name='Serienummer')),
                ('model', models.CharField(blank=True, max_length=200, null=True, verbose_name='Modell')),
                ('hide', models.BooleanField(default=False, verbose_name='Skjul')),
            ],
            options={
                'ordering': ['number'],
            },
        ),
        migrations.AddField(
            model_name='action',
            name='device',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pimanager.Device'),
        ),
    ]
