{% load static %}
<!doctype html>
<html>
<head>
<meta charset="utf-8">
<title>{{ pimanager|default:"" }}</title>
<link href="{% static "pimanager/pimanager.css" %}" rel="stylesheet" type="text/css">
</head>

<body>
<h1>Pimanager {{ version }}</h1>
<hr>
{% block content %} {% endblock %}
</body>
</html>